@@ -14,5 +14,6 @@
 #' 
 #'
 run_sw <- function() {
-  shiny::runApp(system.file("shiny", package = "statnetWeb"))
+  shiny::runApp(system.file("shiny", package = "statnetWeb"),
+                launch.browswer = TRUE)
 }
\ No newline at end of file
