@@ -4,7 +4,7 @@ library(statnetWeb)
 # Everything that gets displayed inside the app is enclosed in a call to `shinyUI`.
 # The first thing to be specified is the type of page to display. The `navbarPage`
 # includes a navigation bar at the top of the page and each tab leads to different
-# pages of content. 
+# pages of content.
 
 shinyUI(
   navbarPage(
@@ -54,26 +54,41 @@ tabPanel(title=span('statnetWeb', id="sWtitle"),
               "or by email to the statnet_help mailing list (see", actionLink("helpLink", "Help"), "tab).")
           ),
           div(id="citebox",
-            p('If you use statnet or statnetWeb, please cite them. BibTeX entries are below.'),
-            p(strong("statnet")),
-
+            tabsetPanel(
+              tabPanel("BibTeX",
+p(strong("statnet")),
 tags$pre(id='scitation','@Manual{handcock:statnet,
-title = {statnet: Software tools for the Statistical Modeling of Network Data},
-author = {Mark S. Handcock and David R. Hunter and Carter T. Butts and Steven M. Goodreau and Martina Morris},
-year = {2003},
-address = {Seattle, WA},
-url = {http://statnetproject.org}
+  title = {statnet: Software tools for the Statistical Modeling of Network Data},
+  author = {Mark S. Handcock and David R. Hunter and Carter T. Butts and Steven M. Goodreau and Martina Morris},
+  year = {2003},
+  address = {Seattle, WA},
+  url = {http://statnetproject.org}
 }'),
 
 p(strong("statnetWeb")),
-tags$pre(id='swcitation','@Unpublished{beylerian:statnetWeb,
-title = {statnetWeb: An R-Shiny interface for statnet network analysis software},
-author = {Emily Beylerian and Martina Morris and Samuel Jenness and Kirk Li},
-year = {2014},
-address = {Seattle, WA},
-url = {https://github.com/statnet/statnetWeb}
-}'),
-            p('Additional citation information for statnet',
+tags$pre(id='swcitation',"@Manual{beylerian:statnetWeb,
+  title = {\\pkg{statnetWeb}: A Graphical User Interface for Network Modeling with 'Statnet'},
+  author = {Emily N. Beylerian and Samuel Jenness and Kirk Li and Martina Morris},
+  year = {2015},
+  note = {\\proglang{R}~package version~0.3.4},
+  address = {Seattle, WA},
+  url = {https://cran.r-project.org/web/packages/statnetWeb/}
+}")
+                       ),
+              tabPanel("Other",
+p(strong("statnet")),
+tags$pre("Mark S. Handcock, David R. Hunter, Carter T. Butts, Steven M. Goodreau, and
+Martina Morris (2003). statnet: Software tools for the Statistical Modeling
+of Network Data. URL http://statnetproject.org"),
+
+p(strong("statnetWeb")),
+tags$pre("Emily N. Beylerian, Samuel Jenness, Kirk Li, and Martina Morris (2014).
+statnetWeb: A Graphical User Interface for Network Modeling with 'Statnet'.")
+                       )
+            ),
+
+            p('If you use statnet or statnetWeb, please cite them.',
+              'Additional citation information for statnet',
               'and the component packages can be found here:'),
             tags$ul(
               tags$li(a('Citing statnet',
@@ -172,7 +187,7 @@ tabPanel(title='Data', value='tab2',
                               });'))
            )
          ),
-         
+
 # Conditional panels are only displayed when a specified condition is true.
 # The condition is a javascript expression that can refer to the current
 # values of input or output objects. When the condition is false, the panel
@@ -202,8 +217,8 @@ fluidRow(
              conditionalPanel(condition = 'input.filetype == 5',
                 column(6,
                     br(style="line-height:26px;"),
-                    selectInput('samplenet', label=NULL,
-                                choices=c('Choose a network', 'ecoli1', 'ecoli2',
+                    selectizeInput('samplenet', label=NULL,
+                                choices=c("Choose a network" = '', 'ecoli1', 'ecoli2',
                                           'faux.mesa.high','flobusiness',
                                           'flomarriage', 'kapferer', 'kapferer2',
                                           'molecule', 'samplike', 'samplk1',
@@ -274,7 +289,7 @@ fluidRow(
                               )
            )),
          conditionalPanel(
-           condition="input.filetype == 5 & input.samplenet != 'Choose a network'",
+           condition="input.filetype == 5 & input.samplenet != ''",
            wellPanel(uiOutput("datadesc"))
            )
          ),
@@ -478,8 +493,11 @@ fluidRow(
  column(7,
     tabsetPanel(id='plottabs',
       tabPanel('Network Plot', br(),
-               plotOutput('nwplot')
+                plotOutput('nwplot')
         ),
+      tabPanel('Attributes', br(),
+              dataTableOutput("attrtbl")
+               ),
       tabPanel('Degree Distribution',
                p(class='helper', id='ddhelper', icon('question-circle')),
                div(class='mischelperbox', id='ddhelperbox',
@@ -501,7 +519,7 @@ fluidRow(
                plotOutput('geodistplot')
                ),
       tabPanel('More', value='More', br(),
-               h5('Conditional uniform graph tests', icon('angle-double-down'),
+               h5('Conditional uniform graph tests', icon('angle-double-left'),
                   id="cugtitle"),
                wellPanel(id="cugbox",
                  column(4, uiOutput("dynamiccugterm")),
@@ -513,14 +531,20 @@ fluidRow(
                  br(),
                  plotOutput("cugtest"),
                  br(),
-                 downloadButton('cugtestdownload', label = "Download Plot", 
+                 downloadButton('cugtestdownload', label = "Download Plot",
                                 class="btn-sm")
                ),
                h5('Mixing matrix', icon('angle-double-left'),
                   id="mixmxtitle"),
                wellPanel(id="mixmxbox",
-                 uiOutput('mixmxchooser'),
-                 verbatimTextOutput('mixingmatrix')
+                 fluidRow(
+                   column(6, uiOutput('mixmxchooser')),
+                   column(6, downloadButton("mixmxdownload",
+                                            class = "shiftdown25"))
+                 ),
+                 fluidRow(
+                   verbatimTextOutput('mixingmatrix')
+                 )
                ),
                h5('Graph-level descriptive indices',
                   icon('angle-double-left'), id="graphleveltitle"),
@@ -688,65 +712,69 @@ fluidRow(
        tabPanel(title='Display Options', br(),
           wellPanel(
                 conditionalPanel(condition='input.plottabs == "Network Plot"',
-                                 checkboxInput('iso',
-                                               label = 'Display isolates',
-                                               value = TRUE),
-                                 checkboxInput('vnames',
-                                               label = 'Display vertex names',
-                                               value = FALSE),
-                                 br(),
-                                 sliderInput('transp',
-                                             label = 'Vertex opacity',
-                                             min = 0, max = 1, value = 1),
-                                 br(),
-                                 uiOutput("dynamiccolor"),
-                                 conditionalPanel(condition="Number(output.attrlevels) > 9",
-                                   column(10,
-                                          p(id = "closewarning1", icon(name = "remove"), class = "warning"),
-                                          div(class = "warning", id = "colorwarning1",
-                                              span(tags$u("Note:"),
-                                                   "Color palette becomes a gradient for attributes with more than nine levels.")
-                                          )
-                                   )),
-
-#                                      span(bsAlert(inputId = 'colorwarning'), style='font-size: 0.82em;'),
-                                 uiOutput('dynamicsize'),
-                                 br(),
-                                 downloadButton('nwplotdownload', label = "Download Plot", class="btn-sm")),
-
+                   checkboxInput('iso',
+                                 label = 'Display isolates',
+                                 value = TRUE),
+                   checkboxInput('vnames',
+                                 label = 'Display vertex names',
+                                 value = FALSE),
+                   br(),
+                   sliderInput('transp',
+                               label = 'Vertex opacity',
+                               min = 0, max = 1, value = 1),
+                   br(),
+                   uiOutput("dynamiccolor"),
+                   conditionalPanel(condition="Number(output.attrlevels) > 9",
+                     column(10,
+                            p(id = "closewarning1", icon(name = "remove"), class = "warning"),
+                            div(class = "warning", id = "colorwarning1",
+                                span(tags$u("Note:"),
+                                     "Color palette becomes a gradient for attributes with more than nine levels.")
+                            )
+                     )),
+                   #span(bsAlert(inputId = 'colorwarning'), style='font-size: 0.82em;'),
+                   uiOutput('dynamicsize'),
+                   br(),
+                   actionButton("refreshplot", icon = icon("refresh"),
+                                label = "Refresh Plot", class = "btn-sm"),
+                   downloadButton('nwplotdownload',
+                                  label = "Download Plot", class = "btn-sm")),
+                conditionalPanel(condition='input.plottabs == "Attributes"',
+                                 uiOutput("attrcheck")
+                ),
                 conditionalPanel(condition='input.plottabs == "Degree Distribution"',
-                                 uiOutput("dynamiccmode_dd"),
-                                 uiOutput("dynamiccolor_dd"),
-                                 tags$label("Y-axis units:"), br(),
-                                 actionButton("countButton_dd", label="Count of vertices", class="btn-sm active"),
-                                 actionButton("percButton_dd", label="Percent of vertices", class="btn-sm"),
-                                 br(), br(),
-                                 tags$label('Expected values of null models:'), br(),
-                                 fluidRow(
-                                   column(10,
-                                          checkboxInput('uniformoverlay_dd',
-                                                 label='Conditional uniform graphs (CUG)',
-                                                 value=FALSE)
-                                          ),
+                   uiOutput("dynamiccmode_dd"),
+                   uiOutput("dynamiccolor_dd"),
+                   tags$label("Y-axis units:"), br(),
+                   actionButton("countButton_dd", label="Count of vertices", class="btn-sm active"),
+                   actionButton("percButton_dd", label="Percent of vertices", class="btn-sm"),
+                   br(), br(),
+                   tags$label('Expected values of null models:'), br(),
+                   fluidRow(
+                     column(10,
+                            checkboxInput('uniformoverlay_dd',
+                                   label='Conditional uniform graphs (CUG)',
+                                   value=FALSE)
+                            ),
 
-                                    span(icon('question-circle'), id="cughelper_dd", class="helper",
-                                         div(id="cughelperbox_dd", class="mischelperbox",
-                                             "Draws from the distribution of simple random graphs with the same",
-                                             "fixed density as the observed network. The mean and 95% confidence",
-                                             "intervals for each degree are plotted."))),
-                                 fluidRow(
-                                   column(10,
-                                          checkboxInput('bernoullioverlay_dd',
-                                                 label='Bernoulli random graphs (BRG)',
-                                                 value=FALSE)
-                                          ),
-                                   span(icon('question-circle'), id="brghelper_dd", class="helper",
-                                        div(id="brghelperbox_dd", class="mischelperbox",
-                                            "Draws from the distribution of simple random graphs with the same",
-                                            "stochastic tie probability as the observed network.",
-                                            "The mean and 95% confidence intervals for each degree are plotted."))),
-                                 br(),
-                                 downloadButton('degreedistdownload', label = "Download Plot", class="btn-sm")
+                      span(icon('question-circle'), id="cughelper_dd", class="helper",
+                           div(id="cughelperbox_dd", class="mischelperbox",
+                               "Draws from the distribution of simple random graphs with the same",
+                               "fixed density as the observed network. The mean and 95% confidence",
+                               "intervals for each degree are plotted."))),
+                   fluidRow(
+                     column(10,
+                            checkboxInput('bernoullioverlay_dd',
+                                   label='Bernoulli random graphs (BRG)',
+                                   value=FALSE)
+                            ),
+                     span(icon('question-circle'), id="brghelper_dd", class="helper",
+                          div(id="brghelperbox_dd", class="mischelperbox",
+                              "Draws from the distribution of simple random graphs with the same",
+                              "stochastic tie probability as the observed network.",
+                              "The mean and 95% confidence intervals for each degree are plotted."))),
+                   br(),
+                   downloadButton('degreedistdownload', label = "Download Plot", class="btn-sm")
                   ),
                 conditionalPanel(condition='input.plottabs == "Geodesic Distribution"',
                                  tags$label("Y-axis units:"), br(),
@@ -848,9 +876,9 @@ actionLink('plotright', icon=icon('arrow-right', class='fa-2x'), label=NULL)
                   div(class="placeholder",
                       fluidRow(
                         column(12,
-                               a("Commonly used ergm terms", 
+                               a("Commonly used ergm terms",
                                  href = "http://statnet.csde.washington.edu/EpiModel/nme/d2-ergmterms.html",
-                                 target = "_blank"), br(), 
+                                 target = "_blank"), br(),
                                a("Term cross-reference tables",
                                  href = "http://cran.r-project.org/web/packages/ergm/vignettes/ergm-term-crossRef.html",
                                  target = "_blank"), br(), br()
@@ -869,11 +897,11 @@ actionLink('plotright', icon=icon('arrow-right', class='fa-2x'), label=NULL)
                                     verbatimTextOutput("termdoc")
                                 ),
                                 div(id = "termexpand",
-                                    icon(name = "expand"))
+                                    icon(name = "angle-double-up"))
                                )
-                        
+
                       )
-                  
+
                   )
                  ),
                  tabPanel("Control Options",
@@ -1058,7 +1086,7 @@ tabPanel(title='Goodness of Fit',value='tab6',
            directed networks is ', code('~ idegree + odegree + espartners +
                                         distance'), '.'),
          fluidRow(
-            column(2, 
+            column(2,
                    p("Goodness of fit term:"),
                    selectInput('gofterm', label = NULL,
                                c('Default', 'degree','idegree','odegree',
@@ -1168,10 +1196,11 @@ tabPanel(title='Simulations', value='tab7',
            column(7,
              tabsetPanel(id="simplotpanel",
              tabPanel("Network Plots", br(),
-                 customNumericInput('thissim', class="input-small",
-                                    labelstyle="display:block;",
-                                    label = 'Choose a simulation to plot:',
-                                    min = 1, value = 1),
+                 column(5,
+                        numericInput('thissim',
+                                     label = 'Choose a simulation to plot:',
+                                     min = 1, value = 1)
+                        ),
                  plotOutput('simplot')
                       ),
              tabPanel("Simulation Statistics",
